@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Author: Don Welch
+# Author: Don Welch, Naga Samrat Chowdary Narla
 #
 # Thanks to Henrique M. Holschuh <hmh@debian.org> for various security patches
 #
@@ -26,6 +26,7 @@ from __future__ import generators
 # Std Lib
 import sys
 import os
+import grp
 import fnmatch
 import tempfile
 import socket
@@ -58,8 +59,35 @@ import pexpect
 BIG_ENDIAN = 0
 LITTLE_ENDIAN = 1
 
+def addgroup():
+    lis = []
+    try:
+        fp=open('/etc/cups/cupsd.conf')
+    except IOError:
+        try:
+            if "root" != grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid).gr_name:
+                return [grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid).gr_name]
+        except OSError:
+            return lis
 
+    try:
+        lis = ((re.findall('SystemGroup [\w* ]*',fp.read()))[0].replace('SystemGroup ','')).split(' ')
+    except IndexError:
+        return lis
 
+    if 'root' in lis:
+        lis.remove('root')
+    fp.close()
+    return lis
+
+def list_to_string(lis):
+    if len(lis) == 0:
+        return ""
+    if len(lis) == 1:
+        return str("\""+lis[0]+"\"")
+    if len(lis) >= 1:
+        return "\""+"\", \"".join(lis)+"\" and \""+str(lis.pop())+"\""
+        
 def lock(f):
     log.debug("Locking: %s" % f.name)
     try:
@@ -1005,6 +1033,20 @@ def getEndian():
 def get_password():
     return getpass.getpass("Enter password: ")
 
+def get_password_ui():
+    fp = open("/etc/hp/hplip.conf", "r")
+    qt = "qt3"
+    for line in fp:
+        if string.find(line, "qt4") is not -1 and string.find(line, "yes") is not -1:
+            qt = "qt4"
+    fp.close()
+    if qt is "qt4":
+        from ui4.setupdialog import showPasswordUI
+        username, password = showPasswordUI("Your printer requires to install HP proprietary plugin\nPlease enter root/superuser password to continue")
+    if qt is "qt3":
+        from ui.setupform import showPasswordUI
+        username, password = showPasswordUI("Your priter requires to install HP proprietary plugin\nPlease enter root/superuser password to continue")
+    return password
 
 def run(cmd, log_output=True, password_func=get_password, timeout=1):
     output = cStringIO.StringIO()
@@ -1026,7 +1068,10 @@ def run(cmd, log_output=True, password_func=get_password, timeout=1):
 
             if i == 0: # Password:
                 if password_func is not None:
-                    child.sendline(password_func())
+                    if password_func == "get_password_ui":
+                        child.sendline(get_password_ui())
+                    else:
+                        child.sendline(password_func())
                 else:
                     child.sendline(get_password())
 
@@ -1578,6 +1623,9 @@ def su_sudo():
 
     elif which('gksu'):
         su_sudo_str = 'gksu "%s"'
+    
+    elif which('su'):
+        su_sudo_str = 'su'
 
     return su_sudo_str
 
