@@ -100,6 +100,7 @@ UI_JOB_STORAGE_USERNAME = 106  # Radios w/text entry
 UI_JOB_STORAGE_ID = 107        # Radios w/text entry
 UI_JOB_STORAGE_ID_EXISTS = 108 # Combo
 
+UI_INFO = 109        # Information field, required Information name and Value
 
 # ipp_op_t
 IPP_PAUSE_PRINTER = 0x0010
@@ -202,12 +203,18 @@ def getPPDPath(addtional_paths=None):
 
 def getAllowableMIMETypes():
     """
-        Scan all /etc/cups/*.convs files for allowable file formats.
+        Scan all /etc/cups/*.convs and /usr/share/cups/mime 
+        files for allowable file formats.
     """
-    files = glob.glob("/etc/cups/*.convs")
-
+    paths = []
     allowable_mime_types = []
-
+    files = []
+    if os.path.exists("/etc/cups"):
+        paths.append("/etc/cups/*.convs")
+    if os.path.exists("/usr/share/cups/mime"):
+        paths.append("/usr/share/cups/mime/*.convs")
+    for path in paths:
+        files.extend(glob.glob(path))
     for f in files:
         #log.debug( "Capturing allowable MIME types from: %s" % f )
         conv_file = file(f, 'r')
@@ -474,14 +481,15 @@ def getPPDFile2(stripped_model, ppds): # New PPD find
                     pdls = []
 
                 if (prop.hpcups_build and 'hpijs' not in f) or \
-                    ((prop.hpijs_build and 'hpijs' in pdls) or (prop.hpcups_build and 'hpijs' not in pdls)):
+                    ((prop.hpijs_build and 'hpijs' in pdls) or (prop.hpcups_build and 'hpijs' not in pdls)) or \
+                    ('ps' in pdls):
                     matches.append((f, [p for p in pdls if p and p != 'hpijs']))
 
     log.debug(matches)
     num_matches = len(matches)
 
     if num_matches == 0:
-        log.error("No PPD found for model %s using new algorithm. Trying old algorithm..." % stripped_model)
+        log.warn("No PPD found for model %s using new algorithm. Trying old algorithm..." % stripped_model)
         matches2 = getPPDFile(stripModel(stripped_model), ppds).items()
         log.debug(matches2)
         num_matches2 = len(matches2)
@@ -496,7 +504,8 @@ def getPPDFile2(stripped_model, ppds): # New PPD find
                         pdls = []
 
                     if (prop.hpcups_build and 'hpijs' not in f) or \
-                       ((prop.hpijs_build and 'hpijs' in pdls) or (prop.hpcups_build and 'hpijs' not in pdls)):
+                       ((prop.hpijs_build and 'hpijs' in pdls) or (prop.hpcups_build and 'hpijs' not in pdls)) or \
+                       ('ps' in pdls):
                         matches.append((f, [p for p in pdls if p and p != 'hpijs']))
 
         log.debug(matches)
@@ -750,3 +759,6 @@ def setPasswordCallback(func):
 
 def setPasswordPrompt(prompt):
     return cupsext.setPasswordPrompt(prompt)
+
+def findPPDAttribute(name, spec):
+    return cupsext.findPPDAttribute(name, spec)
