@@ -16,12 +16,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Authors: Don Welch
+# Authors: Don Welch, Naga Samrat Chowdary Narla
 #
 
 # StdLib
 import socket
 import operator
+import commands
 
 # Local
 from base.g import *
@@ -728,8 +729,18 @@ class SetupDialog(QDialog, Ui_Dialog):
         try:
             self.print_ppd = None
             self.ppds = cups.getSystemPPDs()
-            model = cups.stripModel2(self.model)
-            self.print_ppd = cups.getPPDFile2(model, self.ppds)
+            
+            #Check if common ppd name is already given in models.dat(This is needed because in case of devices having more than one derivatives
+            #will have diffrent model name strings in device ID, because of which we don't get the common ppd name for search)
+
+            ppd_name = self.mq.get('ppd-name',0)
+    
+            if ppd_name == 0:    #Means ppd-name is not provided So follow earlier path of getting name from device ID.
+            	model = cups.stripModel2(self.model)
+            	self.print_ppd = cups.getPPDFile2(model, self.ppds)
+            else:
+            	self.print_ppd = cups.getPPDFile2(ppd_name, self.ppds)
+            
         finally:
             QApplication.restoreOverrideCursor()
 
@@ -743,9 +754,12 @@ class SetupDialog(QDialog, Ui_Dialog):
                 if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_MARVELL:
                     fax_ppd_name = "HP-Fax3-hpcups" # Fixed width (2528 pixels) and 300dpi rendering
                     nick = "HP Fax3 hpcups"
-                elif self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP:
+                elif self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP or self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_LEDMSOAP:
                     fax_ppd_name = "HP-Fax2-hpcups" # Fixed width (2528 pixels) and 300dpi rendering
                     nick = "HP Fax2 hpcups"
+                elif self.mq.get('fax-type', FAX_TYPE_LEDM) == FAX_TYPE_LEDM:
+                    fax_ppd_name = "HP-Fax4-hpcups"# Fixed width (2528 pixels) and 300dpi rendering
+                    nick = "HP Fax4 hpcups"
                 else:
                     fax_ppd_name = "HP-Fax-hpcups" # Standard
                     nick = "HP Fax hpcups"
@@ -754,9 +768,12 @@ class SetupDialog(QDialog, Ui_Dialog):
                 if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_MARVELL:
                     fax_ppd_name = "HP-Fax3-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
                     nick = "HP Fax3 hpijs"
-                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP:
+                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP or self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_LEDMSOAP:
                     fax_ppd_name = "HP-Fax2-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
                     nick = "HP Fax2 hpijs"
+                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_LEDM:
+                    fax_ppd_name = "HP-Fax4-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
+                    nick = "HP Fax4 hpijs"
                 else:
                     fax_ppd_name = "HP-Fax-hpijs" # Standard
                     nick = "HP Fax hpijs"
@@ -977,7 +994,8 @@ class SetupDialog(QDialog, Ui_Dialog):
                 self.printer_name not in self.installed_print_devices[self.device_uri]:
 
                 QApplication.restoreOverrideCursor()
-                FailureUI(self, self.__tr("<b>Printer queue setup failed.</b><p>Please restart CUPS and try again."))
+                if os.geteuid!=0 and utils.addgroup()!=[]:
+                    FailureUI(self, self.__tr("<b>Printer queue setup failed. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
             else:
                 # TODO:
                 #service.sendEvent(self.hpssd_sock, EVENT_CUPS_QUEUES_CHANGED, device_uri=self.device_uri)
@@ -1215,9 +1233,9 @@ class SetupDialog(QDialog, Ui_Dialog):
                     self.manual = True
                     self.param = dlg.hn
                     self.bus = 'net'
-
-            self.showDevicesPage()
-
+            if not self.WirelessButton.isChecked():
+                self.showDevicesPage()
+           
         elif p == PAGE_DEVICES:
             row = self.DevicesTableWidget.currentRow()
             self.device_uri = self.DevicesTableWidget.item(row, 0).device_uri
@@ -1244,8 +1262,8 @@ class SetupDialog(QDialog, Ui_Dialog):
                     item = self.RemoveDevicesTableWidget.item(row, 1)
                     printer = unicode(item.data(Qt.UserRole).toString()).encode('utf-8')
                     log.debug("Removing printer: %s" % printer)
-                    cups.delPrinter(printer)
-
+                    if cups.delPrinter(printer) == 0 and os.geteuid!=0 and utils.addgroup()!=[]:
+                            FailureUI(self, self.__tr("<b>Unable to delete printer queue. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
             self.close()
 
         else:
